/* $Id: op.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
# ifndef CPPAD_OP_INCLUDED
# define CPPAD_OP_INCLUDED

/* --------------------------------------------------------------------------
CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell

CppAD is distributed under multiple licenses. This distribution is under
the terms of the 
                    GNU General Public License Version 3.

A copy of this license is included in the COPYING file of this distribution.
Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
-------------------------------------------------------------------------- */

// used by the sparse operators
# include <cppad/local/sparse_pattern.hpp>

// operations
# include <cppad/local/std_math_ad.hpp>
# include <cppad/local/abs_op.hpp>
# include <cppad/local/add_op.hpp>
# include <cppad/local/acos_op.hpp>
# include <cppad/local/asin_op.hpp>
# include <cppad/local/atan_op.hpp>
# include <cppad/local/comp_op.hpp>
# include <cppad/local/cond_op.hpp>
# include <cppad/local/cos_op.hpp>
# include <cppad/local/cosh_op.hpp>
# include <cppad/local/csum_op.hpp>
# include <cppad/local/discrete_op.hpp>
# include <cppad/local/div_op.hpp>
# include <cppad/local/exp_op.hpp>
# include <cppad/local/load_op.hpp>
# include <cppad/local/log_op.hpp>
# include <cppad/local/mul_op.hpp>
# include <cppad/local/parameter_op.hpp>
# include <cppad/local/pow_op.hpp>
# include <cppad/local/print_op.hpp>
# include <cppad/local/sign_op.hpp>
# include <cppad/local/sin_op.hpp>
# include <cppad/local/sinh_op.hpp>
# include <cppad/local/sqrt_op.hpp>
# include <cppad/local/sub_op.hpp>
# include <cppad/local/sparse_binary_op.hpp>
# include <cppad/local/sparse_unary_op.hpp>
# include <cppad/local/store_op.hpp>
# include <cppad/local/tan_op.hpp>
# include <cppad/local/tanh_op.hpp>


# endif
